within HeatConduction.ClosedLoop;
model HeatConductor
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor con1(G = 5) "Thermal conductor"
     annotation(Placement(visible = true, transformation(origin = {40, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Components.Convection con "Convectoin"
    annotation(Placement(visible = true, transformation(origin = {10, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 5) annotation(Placement(visible = true, transformation(origin = {-20, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Components.ThermalConductor con2(G = 5) "Thermal conductor"
    annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Components.HeatCapacitor cap2(
    C = 150000,
    T(fixed=true)) "Thermal capacitor"
    annotation(Placement(visible = true, transformation(origin = {100, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedTemperature preTem "Prescribed temperature"
    annotation(Placement(visible = true, transformation(origin = {-20, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Components.HeatCapacitor cap1(
    C = 150000,
    T(fixed=true)) "Thermal capacitor"
     annotation(Placement(visible = true, transformation(origin = {60, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Sine sine1(amplitude = 5, freqHz = 1 / 86400, offset = 273.15 + 20) annotation(Placement(visible = true, transformation(origin = {-60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temSen "Temperature sensor"
  annotation(Placement(visible = true, transformation(origin = {120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Continuous.LimPID PI(controllerType = Modelica.Blocks.Types.SimpleController.PI, yMax = 1, yMin = 0, k = 1, Ti = 0.5) "Controller" annotation(Placement(visible = true, transformation(origin = {160, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant TSet(k = 273.15 + 20) "Temperature set point"
  annotation(Placement(visible = true, transformation(origin = {110, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Math.Gain gain1(k = 100) annotation(Placement(visible = true, transformation(origin = {210, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Thermal.HeatTransfer.Sources.PrescribedHeatFlow preHeaFlo "Prescribed heat flow"
  annotation(Placement(visible = true, transformation(origin = {190, -20}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
equation
  connect(preHeaFlo.port, cap2.port)
     annotation(Line(points = {{180, -20}, {100, -20}, {100, 12}, {100, 12}}, color = {191, 0, 0}));
  connect(gain1.y, preHeaFlo.Q_flow) annotation(Line(points = {{221, 60}, {240, 60}, {240, -20}, {200, -20}, {200, -20}}, color = {0, 0, 127}));
  connect(gain1.u, PI.y) annotation(Line(points = {{198, 60}, {170, 60}, {170, 60}, {170, 60}}, color = {0, 0, 127}));
  connect(TSet.y, PI.u_s) annotation(Line(points = {{121, 60}, {148, 60}}, color = {0, 0, 127}));
  connect(PI.u_m, temSen.T) annotation(Line(points = {{160, 48}, {160, 48}, {160, 0}, {130, 0}, {130, 0}}, color = {0, 0, 127}));
  connect(con2.port_b, temSen.port) annotation(Line(points = {{90, 0}, {110, 0}, {110, 0}, {110, 0}, {110, 0}}, color = {191, 0, 0}));
  connect(preTem.T, sine1.y) annotation(Line(points = {{-32, 0}, {-48, 0}, {-48, 0}, {-48, 0}}, color = {0, 0, 127}));
  connect(cap1.port, con2.port_a)
     annotation(Line(points = {{60, 10}, {59, 10}, {59, 0}, {70, 0}}, color = {191, 0, 0}));
  connect(preTem.port, con.fluid) annotation(Line(points = {{-10, 0}, {0, 0}, {0, 0}, {0, 0}}, color = {191, 0, 0}));
  connect(con2.port_b, cap2.port)
    annotation(Line(points = {{90, 0}, {100, 0}, {100, 12}, {100, 12}}, color = {191, 0, 0}));
  connect(con2.port_a, con1.port_b) annotation(Line(points = {{70, 0}, {50, 0}, {50, 0}, {50, 0}}, color = {191, 0, 0}));
  connect(con.Gc, const.y) annotation(Line(points = {{10, 10}, {10, 30}, {-9, 30}}, color = {0, 0, 127}));
  connect(con1.port_a, con.solid) annotation(Line(points = {{30, 0}, {20, 0}}, color = {191, 0, 0}));
  annotation(experiment(StopTime = 864000), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})), Diagram(coordinateSystem(extent = {{-100, -100}, {300, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {2, 2})));
end HeatConductor;
